.. include:: ../../README.rst

Contents:

.. toctree::
   :maxdepth: 2

   installation
   configuration
   extensions
   usage
   changelog

Api documentation:

.. toctree::
   :maxdepth: 2

   modules/modules


Who's Marky Mark?
-----------------

`Marky Mark on WikiPedia <http://en.wikipedia.org/wiki/Mark_Wahlberg>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
